pub struct CommandStatus<VS> {
pub status: Status<VS>,
pub num_hci_command_packets: u8,
pub opcode: Opcode,
}Expand description
The Command Status event is used to indicate that the command described
by the opcode parameter has been received, and that the Controller is
currently performing the task for this command.
Defined in Vol 2, Part E, Section 7.7.15 of the spec.
Fields
status: Status<VS>Status of the command that has started.
num_hci_command_packets: u8Number of HCI Command packets that can be sent to the controller from the host.
opcode: OpcodeOpcode of the command that generated this event. The controller can generate a spontaneous
Command Status with opcode 0 if the number of allowed HCI commands
has changed.