pub struct ConnectionComplete<VS> {
pub status: Status<VS>,
pub conn_handle: ConnectionHandle,
pub bd_addr: BdAddr,
pub link_type: LinkType,
pub encryption_enabled: bool,
}Expand description
The Connection Complete event indicates to both of the Hosts forming the connection that a new connection has been established.
This event also indicates to the Host which issued the connection command and then received a Command Status event, if the issued command failed or was successful.
Fields
status: Status<VS>Did the connection attempt fail, and if so, how?
conn_handle: ConnectionHandleIdentifies a connection between two BR/ EDR Controllers. This is used as an identifier for transmitting and receiving voice or data.
bd_addr: BdAddrBD ADDR of the other connected device forming the connection.
link_type: LinkTypeType of connection.
encryption_enabled: boolTrue if the connection is encrypted.